##     ______   ___    ___
##    /\  _  \ /\_ \  /\_ \
##    \ \ \L\ \\//\ \ \//\ \      __     __   _ __   ___
##     \ \  __ \ \ \ \  \ \ \   /'__`\ /'_ `\/\`'__\/ __`\
##      \ \ \/\ \ \_\ \_ \_\ \_/\  __//\ \L\ \ \ \//\ \L\ \
##       \ \_\ \_\/\____\/\____\ \____\ \____ \ \_\\ \____/
##        \/_/\/_/\/____/\/____/\/____/\/___L\ \/_/ \/___/
##                                       /\____/
##                                       \_/__/
##
##     This is the Allegro simple include makefile.
##     See makefile.txt for usage.
##     
##     By Johan Henriksson
##     
##     See Allegro's readme.txt for copyright information.
##


######## Default build ######
.PHONY: all
all : shared


#############################################################
################ Plattform specific info ####################
#############################################################


ifdef MINGW32  ###################### MinGW #################
        ALLIBO$ = -lalleg
        ALLIBI$ = -lalleg
        ALODIR$ = $(OBJDIR)obj/mgw/
	MKDIR$  = md
else
        ifdef DJDIR  ################ DJGPP #################
                ALLIBO$ = -lalleg
                ALLIBI$ = -lalleg
                ALODIR$ = $(OBJDIR)obj/djgpp/
		MKDIR$  = md
        else         ########### Unix compatible ############
                ALLIBO$ = `allegro-config --shared`
                ALLIBI$ = `allegro-config --static`
                ALODIR$ = $(OBJDIR)obj/unix/
		MKDIR$  = mkdir
        endif
endif





######################################################
################ Compress targets ####################
######################################################

ifneq ($(wildcard $(DJDIR)/bin/upx.exe),)
 ALCOMP$ = $(DJDIR)/bin/upx.exe --best
else
 ifneq ($(wildcard $(DJDIR)/bin/djp.exe),)
  ALCOMP$ = $(DJDIR)/bin/djp.exe -s
 endif
endif


.PHONY: compress
	ALCOMP$ $(EXEN)
	@echo -------------------------------
	@echo Build has been compressed



######################################################
################# Object targets #####################
######################################################

CC$ = gcc

CFLAGSA$ = -Wall

CFLAGSN$ = -ffast-math -s
LFLAGSN$ = 

ALOBJ$ = $(addprefix $(ALODIR),$(OBJ))


#### Normal compilation
$(addprefix $(ALODIR),%.o) :: %.c $(HEAD) $(OBJDIR)obj
	$(CC) -c $< $(CFLAGSA) $(CFLAGSN) -o $@


######################################################
################### Link targets #####################
######################################################

### Shared linking
.PHONY: shared
shared : $(ALOBJ)
	$(CC) $(ALOBJ) $(LFLAGSN) -o $(EXEN) $(LIBO) $(ALLIBO)
	@echo -------------------------------
	@echo Shared build complete


### Static linking
.PHONY: static
static : $(ALOBJ)
	$(CC) $(ALOBJ) $(LFLAGSN) -o $(EXEN) $(LIBI) $(ALLIBI)
	@echo -------------------------------
	@echo Static build complete



######################################################
################### FS targets #######################
######################################################

.PHONY: fs
fs : $(OBJDIR)obj
	@echo -------------------------------------
	@echo Filestructure has been prepared
	

$(OBJDIR)obj :
	$(MKDIR) $(OBJDIR)obj
	$(MKDIR) $(OBJDIR)obj/djgpp
	$(MKDIR) $(OBJDIR)obj/mgw
	$(MKDIR) $(OBJDIR)obj/unix


######################################################
################### Clean targets ####################
######################################################

.PHONY: removeob
removeob :
	$(RM) $(addprefix $(ALODIR),$(OBJ))
.PHONY: removeex
removeex :
	$(RM) $(EXEN)
	


.PHONY: clean
clean : removeob removeex
	@echo --------------------------------------------------
	@echo Objects and executable has been removed

	
.PHONY: mostlyclean
mostlyclean : removeob
	@echo --------------------------------------------------
	@echo Objects has been removed

	

